===============================
QRedis
===============================


.. image:: https://img.shields.io/travis/tiagocoutinho/qredis.svg
        :target: https://travis-ci.org/tiagocoutinho/qredis


The QRedis App
